@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp qw/confess/;
 
-our $VERSION = '0.000077';
+our $VERSION = '0.000078';
 
 use base 'DBIx::Class::Schema';
 
@@ -19,7 +19,10 @@ BEGIN {
     __PACKAGE__->table("coverage");
 }
 
-__PACKAGE__->load_namespaces;
+require Test2::Harness::UI::Schema::ResultSet;
+__PACKAGE__->load_namespaces(
+    default_resultset_class => 'ResultSet',
+);
 
 require Test2::Harness::UI::Schema::Result::ApiKey;
 require Test2::Harness::UI::Schema::Result::Email;
